@@ -13,7 +13,7 @@
 #'     action will be taken.
 #' @param ... not used.
 #'
-#' @return Zero (invisibly) on success.
+#' @return Invisibly, an integer exit code (zero on success).
 #'
 #' @name start
 #' @rdname start
@@ -27,7 +27,12 @@ NULL
 start.nanoListener <- function(x, ...) {
 
   xc <- .Call(rnng_listener_start, x)
-  if (xc) message(xc, " : ", nng_error(xc))
+  if (xc) {
+    logerror(xc)
+  } else if (logging()) {
+    loginfo(evt = "list start", pkey = "sock", pval = attr(x, "socket"),
+            skey = "url", sval = attr(x, "url"))
+  }
   invisible(xc)
 
 }
@@ -39,7 +44,12 @@ start.nanoListener <- function(x, ...) {
 start.nanoDialer <- function(x, async = TRUE, ...) {
 
   xc <- .Call(rnng_dialer_start, x, async)
-  if (xc) message(xc, " : ", nng_error(xc))
+  if (xc) {
+    logerror(xc)
+  } else if (logging()) {
+    loginfo(evt = "dial start", pkey = "sock", pval = attr(x, "socket"),
+            skey = "url", sval = attr(x, "url"))
+  }
   invisible(xc)
 
 }
@@ -51,7 +61,7 @@ start.nanoDialer <- function(x, async = TRUE, ...) {
 #' @param con a Socket, Context, Dialer or Listener.
 #' @param ... not used.
 #'
-#' @return Zero (invisibly) on success.
+#' @return Invisibly, an integer exit code (zero on success).
 #'
 #' @details Closing an object explicitly frees its resources. An object can also
 #'     be removed directly in which case its resources are freed when the object
@@ -80,7 +90,12 @@ NULL
 close.nanoSocket <- function(con, ...) {
 
   xc <- .Call(rnng_close, con)
-  if (xc) message(xc, " : ", nng_error(xc))
+  if (xc) {
+    logerror(xc)
+  } else if (logging()) {
+    loginfo(evt = "sock close", pkey = "id", pval = attr(con, "id"),
+            skey = "protocol", sval = attr(con, "protocol"))
+  }
   invisible(xc)
 
 }
@@ -92,7 +107,7 @@ close.nanoSocket <- function(con, ...) {
 close.nanoContext <- function(con, ...) {
 
   xc <- .Call(rnng_ctx_close, con)
-  if (xc) message(xc, " : ", nng_error(xc))
+  if (xc) logerror(xc)
   invisible(xc)
 
 }
@@ -104,7 +119,13 @@ close.nanoContext <- function(con, ...) {
 close.nanoDialer <- function(con, ...) {
 
   xc <- .Call(rnng_dialer_close, con)
-  if (xc) message(xc, " : ", nng_error(xc))
+  if (xc) {
+    logerror(xc)
+  } else if (logging()) {
+    loginfo(evt = "dial close", pkey = "sock", pval = attr(con, "socket"),
+            skey = "url", sval = attr(con, "url"))
+  }
+
   invisible(xc)
 
 }
@@ -116,7 +137,13 @@ close.nanoDialer <- function(con, ...) {
 close.nanoListener <- function(con, ...) {
 
   xc <- .Call(rnng_listener_close, con)
-  if (xc) message(xc, " : ", nng_error(xc))
+  if (xc) {
+    logerror(xc)
+  } else if (logging()) {
+    loginfo(evt = "list close", pkey = "sock", pval = attr(con, "socket"),
+            skey = "url", sval = attr(con, "url"))
+  }
+
   invisible(xc)
 
 }
