@@ -19,9 +19,11 @@ extern SEXP nano_UrlSymbol;
 extern SEXP nano_AioSymbol;
 
 /* define functions */
+extern SEXP rnng_aio_call(SEXP);
 extern SEXP rnng_aio_get_msg(SEXP);
 extern SEXP rnng_aio_result(SEXP);
 extern SEXP rnng_aio_stop(SEXP);
+extern SEXP rnng_aio_unresolv(void);
 extern SEXP rnng_close(SEXP);
 extern SEXP rnng_ctx_close(SEXP);
 extern SEXP rnng_ctx_open(SEXP);
@@ -53,10 +55,11 @@ extern SEXP rnng_listener_set_size(SEXP, SEXP, SEXP);
 extern SEXP rnng_listener_set_string(SEXP, SEXP, SEXP);
 extern SEXP rnng_listener_set_uint64(SEXP, SEXP, SEXP);
 extern SEXP rnng_listener_start(SEXP);
-extern SEXP rnng_ncurl(SEXP);
+extern SEXP rnng_ncurl(SEXP, SEXP);
 extern SEXP rnng_protocol_open(SEXP);
 extern SEXP rnng_recv(SEXP, SEXP);
 extern SEXP rnng_recv_aio(SEXP, SEXP);
+extern SEXP rnng_scm(void);
 extern SEXP rnng_send(SEXP, SEXP, SEXP);
 extern SEXP rnng_send_aio(SEXP, SEXP, SEXP);
 extern SEXP rnng_socket_set_bool(SEXP, SEXP, SEXP);
@@ -66,7 +69,6 @@ extern SEXP rnng_socket_set_size(SEXP, SEXP, SEXP);
 extern SEXP rnng_socket_set_string(SEXP, SEXP, SEXP);
 extern SEXP rnng_socket_set_uint64(SEXP, SEXP, SEXP);
 extern SEXP rnng_strerror(SEXP);
-extern SEXP rnng_threaded_timer(SEXP);
 extern SEXP rnng_version(void);
 
 #endif
