@@ -3,7 +3,6 @@
 #include <nng/nng.h>
 #include <nng/supplemental/http/http.h>
 #include <nng/supplemental/tls/tls.h>
-#include <nng/supplemental/util/platform.h>
 #include "nanonext.h"
 
 SEXP rnng_strerror(SEXP error) {
@@ -17,7 +16,7 @@ SEXP rnng_strerror(SEXP error) {
 SEXP rnng_version(void) {
 
   const char *ver = nng_version();
-  struct nng_tls_config *cfg;
+  nng_tls_config *cfg;
   int xc = nng_tls_config_alloc(&cfg, 0);
   char *tls;
   if (xc) {
@@ -34,40 +33,13 @@ SEXP rnng_version(void) {
 
 }
 
-static void thread_finalizer(SEXP xptr) {
-
-  if (R_ExternalPtrAddr(xptr) == NULL)
-    return;
-  nng_thread *xp = (nng_thread *) R_ExternalPtrAddr(xptr);
-  nng_thread_destroy(xp);
-  R_ClearExternalPtr(xptr);
-
+SEXP rnng_scm() {
+  return R_MissingArg;
 }
 
-static void rnng_timer(void *arg) {
+/* ncurl - minimalist http client ------------------------------------------- */
 
-  SEXP time = PROTECT(arg);
-  const int tm = INTEGER(time)[0];
-  nng_msleep(tm);
-  UNPROTECT(1);
-  REprintf("Timer completed after %d ms\n", tm);
-
-}
-
-SEXP rnng_threaded_timer(SEXP time) {
-
-  nng_thread *thr;
-  nng_thread_create(&thr, rnng_timer, time);
-  SEXP xptr = PROTECT(R_MakeExternalPtr(thr, R_NilValue, R_NilValue));
-  R_RegisterCFinalizerEx(xptr, thread_finalizer, TRUE);
-  UNPROTECT(1);
-  return xptr;
-
-}
-
-/* ncurl - minimalistic http client ----------------------------------------- */
-
-SEXP rnng_ncurl(SEXP http) {
+SEXP rnng_ncurl(SEXP http, SEXP args) {
 
   nng_url *url;
   nng_http_client *client;
@@ -82,25 +54,44 @@ SEXP rnng_ncurl(SEXP http) {
   int tls = 0;
 
   const char *httr = CHAR(STRING_ELT(http, 0));
-  if ((xc = nng_url_parse(&url, httr))) {
+  xc = nng_url_parse(&url, httr);
+  if (xc)
     return Rf_ScalarInteger(xc);
-  }
-  if ((xc = nng_http_client_alloc(&client, url))) {
+  xc = nng_http_client_alloc(&client, url);
+  if (xc) {
     nng_url_free(url);
     return Rf_ScalarInteger(xc);
   }
-  if ((xc = nng_http_req_alloc(&req, url))) {
+  xc = nng_http_req_alloc(&req, url);
+  if (xc) {
     nng_http_client_free(client);
     nng_url_free(url);
     return Rf_ScalarInteger(xc);
   }
-  if ((xc = nng_http_res_alloc(&res))) {
+  if (args != R_NilValue) {
+    const char *method = CHAR(STRING_ELT(VECTOR_ELT(args, 0), 0));
+    const char *ctype = CHAR(STRING_ELT(VECTOR_ELT(args, 1), 0));
+    const SEXP data = VECTOR_ELT(args, 2);
+    unsigned char *dp = RAW(data);
+    const R_xlen_t dlen = XLENGTH(data) - 1;
+    if ((xc = nng_http_req_set_method(req, method)) ||
+        (xc = nng_http_req_set_header(req, "Content-Type", ctype)) ||
+        (xc = nng_http_req_set_data(req, dp, dlen))) {
+      nng_http_req_free(req);
+      nng_http_client_free(client);
+      nng_url_free(url);
+      return Rf_ScalarInteger(xc);
+    }
+  }
+  xc = nng_http_res_alloc(&res);
+  if (xc) {
     nng_http_req_free(req);
     nng_http_client_free(client);
     nng_url_free(url);
     return Rf_ScalarInteger(xc);
   }
-  if ((xc = nng_aio_alloc(&aio, NULL, NULL))) {
+  xc = nng_aio_alloc(&aio, NULL, NULL);
+  if (xc) {
     nng_http_res_free(res);
     nng_http_req_free(req);
     nng_http_client_free(client);
@@ -109,7 +100,8 @@ SEXP rnng_ncurl(SEXP http) {
   }
 
   if (!strcmp(url->u_scheme, "https")) {
-    if ((xc = nng_tls_config_alloc(&cfg, 0))) {
+    xc = nng_tls_config_alloc(&cfg, 0);
+    if (xc) {
       nng_aio_free(aio);
       nng_http_res_free(res);
       nng_http_req_free(req);
@@ -132,7 +124,8 @@ SEXP rnng_ncurl(SEXP http) {
 
   nng_http_client_transact(client, req, res, aio);
   nng_aio_wait(aio);
-  if ((xc = nng_aio_result(aio))) {
+  xc = nng_aio_result(aio);
+  if (xc) {
     if (tls)
       nng_tls_config_free(cfg);
     nng_aio_free(aio);
