@@ -3,10 +3,10 @@
 if (!file.exists("../windows/rwinlib-1.5.2/include/nng.h")) {
 
   if (getRversion() < "3.3.0") setInternet2()
-  download.file("https://github.com/shikokuchuo/rwinlib/archive/refs/tags/v1.5.2.zip", destfile = "nng-latest.zip", quiet = TRUE)
+  download.file("https://github.com/shikokuchuo/rwinlib/archive/refs/tags/v1.5.2.zip", destfile = "nng-release.zip", quiet = TRUE)
   dir.create("../windows", showWarnings = FALSE)
-  unzip("nng-latest.zip", exdir = "../windows")
-  unlink("nng-latest.zip")
+  unzip("nng-release.zip", exdir = "../windows")
+  unlink("nng-release.zip")
 
 }
 
